@@ -577,7 +577,7 @@ void SystemTray::mousePressEvent(TQMouseEvent *e)
         KSystemTray::mousePressEvent(e);
         break;
     case Qt::MidButton:
-        if(!TQT_TQRECT_OBJECT(rect()).contains(e->pos()))
+        if(!rect().contains(e->pos()))
             return;
         if(action("pause")->isEnabled())
             action("pause")->activate();
@@ -635,5 +635,3 @@ static bool copyImage(TQImage &dest, TQImage &src, int x, int y)
 
 
 #include "systemtray.moc"
-
-// vim: et sw=4 ts=8
