@@ -57,7 +57,7 @@
  */
 MDWSlider::MDWSlider(Mixer *mixer, MixDevice* md,
                                  bool showMuteLED, bool showRecordLED,
-                                 bool small, Qt::Orientation orientation,
+                                 bool small, TQt::Orientation orientation,
                                  TQWidget* parent, ViewBase* mw, const char* name) :
     MixDeviceWidget(mixer,md,small,orientation,parent,mw,name),
     m_linked(true), m_valueStyle( NNONE), m_iconLabel( 0 ), m_muteLED( 0 ), m_recordLED( 0 ), m_label( 0 ), _layout(0)
@@ -96,7 +96,7 @@ MDWSlider::MDWSlider(Mixer *mixer, MixDevice* md,
 
 TQSizePolicy MDWSlider::sizePolicy() const
 {
-	if ( _orientation == Qt::Vertical ) {
+	if ( _orientation == TQt::Vertical ) {
 		return TQSizePolicy(  TQSizePolicy::Fixed, TQSizePolicy::Expanding );
 	}
 	else {
@@ -113,18 +113,17 @@ TQSizePolicy MDWSlider::sizePolicy() const
 */
 void MDWSlider::createWidgets( bool showMuteLED, bool showRecordLED )
 {
-    if ( _orientation == Qt::Vertical ) {
-	_layout = new TQVBoxLayout( this );
-	_layout->setAlignment(TQt::AlignCenter);
+    if ( _orientation == TQt::Vertical ) {
+	   _layout = new TQVBoxLayout( this );
     }
     else {
-	_layout = new TQHBoxLayout( this );
-	_layout->setAlignment(TQt::AlignCenter);
+	   _layout = new TQHBoxLayout( this );
     }
+    _layout->setAlignment(TQt::AlignCenter);
 
 	 // -- MAIN SLIDERS LAYOUT  ---
 	 TQBoxLayout *slidersLayout;
-	 if ( _orientation == Qt::Vertical ) {
+	 if ( _orientation == TQt::Vertical ) {
 		 slidersLayout = new TQHBoxLayout( _layout );
 		 slidersLayout->setAlignment(TQt::AlignVCenter);
 	 }
@@ -136,14 +135,14 @@ void MDWSlider::createWidgets( bool showMuteLED, bool showRecordLED )
 	 /* cesken: This is inconsistent. Why should vertical and horizontal layout differ?
 	  *         Also it eats too much space - especially when you don't show sliders at all.
 	  *         Even more on the vertical panel applet (see Bug #97667)
-	     if ( _orientation == Qt::Horizontal )
+	     if ( _orientation == TQt::Horizontal )
 		 slidersLayout->addSpacing( 10 );
 	 */
 
 
 	 // -- LABEL LAYOUT TO POSITION
 	 TQBoxLayout *labelLayout;
-	 if ( _orientation == Qt::Vertical ) {
+	 if ( _orientation == TQt::Vertical ) {
 		 labelLayout = new TQVBoxLayout( slidersLayout );
 		 labelLayout->setAlignment(TQt::AlignHCenter);
 	 }
@@ -151,7 +150,7 @@ void MDWSlider::createWidgets( bool showMuteLED, bool showRecordLED )
 		 labelLayout = new TQHBoxLayout( slidersLayout );
 		 labelLayout->setAlignment(TQt::AlignVCenter);
 	 }
-    if ( _orientation == Qt::Vertical ) {
+    if ( _orientation == TQt::Vertical ) {
 		 m_label = new VerticalText( this, m_mixdevice->name().utf8().data() );
 		TQToolTip::add( m_label, m_mixdevice->name() );
 
@@ -166,7 +165,7 @@ void MDWSlider::createWidgets( bool showMuteLED, bool showRecordLED )
 
 /* This addSpacing() looks VERY bizarre => removing it (cesken, 21.2.2006).
    Also horizontal and vertical spacing differs. This doesn't look sensible.
-    if ( _orientation == Qt::Horizontal )
+    if ( _orientation == TQt::Horizontal )
 		 labelLayout->addSpacing( 36 );
 */
 	 labelLayout->addWidget( m_label );
@@ -174,14 +173,14 @@ void MDWSlider::createWidgets( bool showMuteLED, bool showRecordLED )
 
 /* This addSpacing() looks VERY bizarre => removing it (cesken, 21.2.2006)
    Also horizontal and vertical spacing differs. This doesn't look sensible.
-    if ( _orientation == Qt::Vertical ) {
+    if ( _orientation == TQt::Vertical ) {
 		 labelLayout->addSpacing( 18 );
 	 }
 */
 
 	 // -- SLIDERS, LEDS AND ICON
 	 TQBoxLayout *sliLayout;
-	 if ( _orientation == Qt::Vertical ) {
+	 if ( _orientation == TQt::Vertical ) {
 		 sliLayout = new TQVBoxLayout( slidersLayout );
 		 sliLayout->setAlignment(TQt::AlignHCenter);
     }
@@ -192,7 +191,7 @@ void MDWSlider::createWidgets( bool showMuteLED, bool showRecordLED )
 
 	 // --- ICON  ----------------------------
     TQBoxLayout *iconLayout;
-    if ( _orientation == Qt::Vertical ) {
+    if ( _orientation == TQt::Vertical ) {
 		 iconLayout = new TQHBoxLayout( sliLayout );
 		 iconLayout->setAlignment(TQt::AlignVCenter);
 	 }
@@ -214,7 +213,7 @@ void MDWSlider::createWidgets( bool showMuteLED, bool showRecordLED )
 	 // --- MUTE LED
 	 if ( showMuteLED ) {
 		 TQBoxLayout *ledlayout;
-		 if ( _orientation == Qt::Vertical ) {
+		 if ( _orientation == TQt::Vertical ) {
 			 ledlayout = new TQHBoxLayout( sliLayout );
 			 ledlayout->setAlignment(TQt::AlignVCenter);
 		 }
@@ -251,7 +250,7 @@ void MDWSlider::createWidgets( bool showMuteLED, bool showRecordLED )
 
     // --- SLIDERS ---------------------------
 	 TQBoxLayout *volLayout;
-	 if ( _orientation == Qt::Vertical ) {
+	 if ( _orientation == TQt::Vertical ) {
 		 volLayout = new TQHBoxLayout( sliLayout );
 		 volLayout->setAlignment(TQt::AlignVCenter);
 	 }
@@ -271,7 +270,7 @@ void MDWSlider::createWidgets( bool showMuteLED, bool showRecordLED )
 		 int maxvol = m_mixdevice->getVolume().maxVolume();
 		 int minvol = m_mixdevice->getVolume().minVolume();
 
-		 if ( _orientation == Qt::Vertical ) {
+		 if ( _orientation == TQt::Vertical ) {
 		   slinumLayout = new TQVBoxLayout( volLayout );
 		   slinumLayout->setAlignment(TQt::AlignHCenter);
 		 }
@@ -328,7 +327,7 @@ void MDWSlider::createWidgets( bool showMuteLED, bool showRecordLED )
 
 		 // --- LED LAYOUT TO CENTER ---
 		 TQBoxLayout *reclayout;
-		 if ( _orientation == Qt::Vertical ) {
+		 if ( _orientation == TQt::Vertical ) {
 			 reclayout = new TQHBoxLayout( sliLayout );
 			 reclayout->setAlignment(TQt::AlignVCenter);
 		 }
@@ -471,7 +470,7 @@ MDWSlider::setStereoLinked(bool value)
     ***********************************************************/
    int firstSliderValue = 0;
    bool firstSliderValueValid = false;
-   if (slider->isA(TQSLIDER_OBJECT_NAME_STRING) ) {
+   if (slider->isA("TQSlider") ) {
       TQSlider *sld = static_cast<TQSlider*>(slider);
       firstSliderValue = sld->value();
       firstSliderValueValid = true;
@@ -494,7 +493,7 @@ MDWSlider::setStereoLinked(bool value)
          if ( firstSliderValueValid ) {
             // Remark: firstSlider== 0 could happen, if the static_cast<TQRangeControl*> above fails.
             //         It's a safety measure, if we got other Slider types in the future.
-            if (slider->isA(TQSLIDER_OBJECT_NAME_STRING) ) {
+            if (slider->isA("TQSlider") ) {
                TQSlider *sld = static_cast<TQSlider*>(slider);
                sld->setValue( firstSliderValue );
             }
@@ -539,7 +538,7 @@ MDWSlider::setTicks( bool ticks )
 
 		slider = m_sliders.first();
 
-	if ( slider->inherits( TQSLIDER_OBJECT_NAME_STRING ) )
+	if ( slider->inherits( "TQSlider" ) )
 	{
 		if( ticks )
 			if( isStereoLinked() )
@@ -651,7 +650,7 @@ void MDWSlider::volumeChange( int )
       else {
          TQSlider *slider = dynamic_cast<TQSlider *>(m_sliders.first());
          if (slider) {
-				if ( _orientation == Qt::Vertical )
+				if ( _orientation == TQt::Vertical )
 					sliderValue= slider->maxValue() - slider->value();
 				else
 					sliderValue= slider->value();
@@ -691,7 +690,7 @@ void MDWSlider::volumeChange( int )
 	  {
 	      TQSlider *bigSlider = dynamic_cast<TQSlider *>(slider);
 	      if (bigSlider)
-				if ( _orientation == Qt::Vertical )
+				if ( _orientation == TQt::Vertical )
 					vol.setVolume( chid, bigSlider->maxValue() - bigSlider->value() );
 				else
 					vol.setVolume( chid, bigSlider->value() );
@@ -760,15 +759,7 @@ void MDWSlider::setDisabled( bool value )
 */
 void MDWSlider::increaseVolume()
 {
-	Volume vol = m_mixdevice->getVolume();
-	long inc = vol.maxVolume() / 20;
-	if ( inc == 0 )
-		inc = 1;
-	for ( int i = 0; i < vol.count(); i++ ) {
-		long newVal = (vol[i]) + inc;
-		m_mixdevice->setVolume( i, newVal < vol.maxVolume() ? newVal : vol.maxVolume() );
-	}
-	m_mixer->commitVolumeChange(m_mixdevice);
+	m_mixer->increaseVolume(m_mixdevice->num(), 5);
 }
 
 /**
@@ -777,15 +768,7 @@ void MDWSlider::increaseVolume()
 */
 void MDWSlider::decreaseVolume()
 {
-	Volume vol = m_mixdevice->getVolume();
-	long inc = vol.maxVolume() / 20;
-	if ( inc == 0 )
-		inc = 1;
-	for ( int i = 0; i < vol.count(); i++ ) {
-		long newVal = (vol[i]) - inc;
-		m_mixdevice->setVolume( i, newVal > 0 ? newVal : 0 );
-	}
-	m_mixer->commitVolumeChange(m_mixdevice);
+	m_mixer->decreaseVolume(m_mixdevice->num(), 5);
 }
 
 
@@ -824,7 +807,7 @@ void MDWSlider::update()
 				// show the top of both volumes, and not strangely low down
 				// the main volume by half
 
-				if ( _orientation == Qt::Vertical )
+				if ( _orientation == TQt::Vertical )
 					bigSlider->setValue( vol.maxVolume() - vol.getTopStereoVolume( Volume::MMAIN ) );
 				else
 					bigSlider->setValue( vol.getTopStereoVolume( Volume::MMAIN ) );
@@ -860,7 +843,7 @@ void MDWSlider::update()
 			{
 				TQSlider *bigSlider = dynamic_cast<TQSlider *>(slider);
 				if (bigSlider)
-					if ( _orientation == Qt::Vertical ) {
+					if ( _orientation == TQt::Vertical ) {
 						bigSlider->setValue( vol.maxVolume() - vol[i] );
 					}
 					else {
@@ -952,7 +935,7 @@ bool MDWSlider::eventFilter( TQObject* obj, TQEvent* e )
 {
     if (e->type() == TQEvent::MouseButtonPress) {
 	TQMouseEvent *qme = TQT_TQMOUSEEVENT(e);
-	if (qme->button() == Qt::RightButton) {
+	if (qme->button() == TQt::RightButton) {
 	    showContextMenu();
 	    return true;
 	}
