@@ -9,7 +9,7 @@ class Mixer;
 
 class ViewSliders : public ViewBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     ViewSliders(TQWidget* parent, const char* name, const TQString & caption, Mixer* mixer, ViewBase::ViewFlags vflags);
