@@ -16,7 +16,7 @@ struct MetaWidget {
 };
 
 class Editor:public KDialogBase {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     Editor();
