@@ -5,7 +5,7 @@
 #include "waWidget.h"
 
 class WaClutterbar : public WaWidget {
-    Q_OBJECT
+    TQ_OBJECT
   
 
   public:
