@@ -28,7 +28,7 @@
 
 
 class WaTitleBar : public WaIndicator {
-    Q_OBJECT
+    TQ_OBJECT
   
 
   public:
