@@ -5,7 +5,7 @@
 #include "waSkinModel.h"
 
 class WaWidget : public TQWidget {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     WaWidget(int mapping);
